@@ -6,13 +6,16 @@ use base qw(CHI::t::Driver);
 
 sub testing_driver_class { 'CHI::Driver::Redis' }
 
+sub supports_expires_on_backend { 1 }
+
 sub new_cache_options {
     my $self = shift;
 
     return (
         $self->SUPER::new_cache_options(),
         driver_class => 'CHI::Driver::Redis',
-        server => '127.0.0.1:6379',
+        server => $ENV{CHI_REDIS_SERVER} || '127.0.0.1:6379',
+        ($ENV{CHI_REDIS_PASSWORD} ? ( password => $ENV{CHI_REDIS_PASSWORD} ) : ()),
     );
 }
 
@@ -24,4 +27,4 @@ sub clear_redis : Test(setup) {
     $cache->redis->flushall;
 }
 
-1;
\ No newline at end of file
+1;
